@@ -1,7 +1,8 @@
 #!/usr/bin/env bash
 
 # This script handles any custom processing of the spec file using the `fix-spec-file`
-# action in .packit.yaml.
+# action in .packit.yaml. These steps only work on copr builds, not on official
+# Fedora builds.
 
 set -eox pipefail
 
@@ -10,6 +11,9 @@ PACKAGE=podman
 # Set path to rpm spec file
 SPEC_FILE=rpm/$PACKAGE.spec
 
+# Get short sha
+SHORT_SHA=$(git rev-parse --short HEAD)
+
 # Get Version from HEAD
 VERSION=$(grep '^const RawVersion' version/rawversion/version.go | cut -d\" -f2)
 
@@ -36,3 +40,9 @@ sed -i "s/^Source0:.*.tar.gz/Source0: $PACKAGE-$VERSION.tar.gz/" $SPEC_FILE
 
 # Update setup macro to use the correct build dir
 sed -i "s/^%autosetup.*/%autosetup -Sgit -n %{name}-$VERSION/" $SPEC_FILE
+
+# Update relevant sed entries in spec file with the actual VERSION and SHORT_SHA
+# This allows podman --version to also show the SHORT_SHA along with the
+# VERSION
+sed -i "s/##VERSION##/$VERSION/" $SPEC_FILE
+sed -i "s/##SHORT_SHA##/$SHORT_SHA/" $SPEC_FILE
