@@ -4,9 +4,9 @@ import (
 	"context"
 	"errors"
 
-	"github.com/containers/podman/v4/libpod/define"
-	"github.com/containers/podman/v4/pkg/bindings/system"
-	"github.com/containers/podman/v4/pkg/domain/entities"
+	"github.com/containers/podman/v5/libpod/define"
+	"github.com/containers/podman/v5/pkg/bindings/system"
+	"github.com/containers/podman/v5/pkg/domain/entities"
 )
 
 func (ic *ContainerEngine) Info(ctx context.Context) (*define.Info, error) {
@@ -23,6 +23,18 @@ func (ic *ContainerEngine) SystemPrune(ctx context.Context, opts entities.System
 	return system.Prune(ic.ClientCtx, options)
 }
 
+func (ic *ContainerEngine) Migrate(ctx context.Context, options entities.SystemMigrateOptions) error {
+	return errors.New("runtime migration is not supported on remote clients")
+}
+
+func (ic *ContainerEngine) Renumber(ctx context.Context) error {
+	return errors.New("lock renumbering is not supported on remote clients")
+}
+
+func (ic *ContainerEngine) Reset(ctx context.Context) error {
+	return errors.New("system reset is not supported on remote clients")
+}
+
 func (ic *ContainerEngine) SystemDf(ctx context.Context, options entities.SystemDfOptions) (*entities.SystemDfReport, error) {
 	return system.DiskUsage(ic.ClientCtx, nil)
 }
@@ -34,3 +46,7 @@ func (ic *ContainerEngine) Unshare(ctx context.Context, args []string, options e
 func (ic ContainerEngine) Version(ctx context.Context) (*entities.SystemVersionReport, error) {
 	return system.Version(ic.ClientCtx, nil)
 }
+
+func (ic ContainerEngine) Locks(ctx context.Context) (*entities.LocksReport, error) {
+	return nil, errors.New("locks is not supported on remote clients")
+}
