@@ -8,17 +8,14 @@ import (
 	"strconv"
 	"strings"
 
-	. "github.com/containers/podman/v4/test/utils"
-	. "github.com/onsi/ginkgo"
+	. "github.com/containers/podman/v5/test/utils"
+	. "github.com/onsi/ginkgo/v2"
 	. "github.com/onsi/gomega"
-	. "github.com/onsi/gomega/gexec"
 )
 
 var _ = Describe("Podman login and logout", func() {
 	var (
-		tempdir                  string
 		err                      error
-		podmanTest               *PodmanTestIntegration
 		authPath                 string
 		certPath                 string
 		certDirPath              string
@@ -28,32 +25,13 @@ var _ = Describe("Podman login and logout", func() {
 	)
 
 	BeforeEach(func() {
-		tempdir, err = CreateTempDirInTempDir()
-		if err != nil {
-			os.Exit(1)
-		}
-		podmanTest = PodmanTestCreate(tempdir)
-
 		authPath = filepath.Join(podmanTest.TempDir, "auth")
 		err := os.Mkdir(authPath, os.ModePerm)
 		Expect(err).ToNot(HaveOccurred())
 
-		if IsCommandAvailable("getenforce") {
-			ge := SystemExec("getenforce", []string{})
-			ge.WaitWithDefaultTimeout()
-			if ge.OutputToString() == "Enforcing" {
-				se := SystemExec("setenforce", []string{"0"})
-				se.WaitWithDefaultTimeout()
-				if se.ExitCode() != 0 {
-					Skip("Cannot disable selinux, this may cause problem for reading cert files inside container.")
-				}
-				defer SystemExec("setenforce", []string{"1"})
-			}
-		}
-
 		htpasswd := SystemExec("htpasswd", []string{"-Bbn", "podmantest", "test"})
 		htpasswd.WaitWithDefaultTimeout()
-		Expect(htpasswd).Should(Exit(0))
+		Expect(htpasswd).Should(ExitCleanly())
 
 		f, err := os.Create(filepath.Join(authPath, "htpasswd"))
 		Expect(err).ToNot(HaveOccurred())
@@ -86,15 +64,18 @@ var _ = Describe("Podman login and logout", func() {
 			"-v", strings.Join([]string{certPath, "/certs:Z"}, ":"), "-e", "REGISTRY_HTTP_TLS_CERTIFICATE=/certs/domain.crt",
 			"-e", "REGISTRY_HTTP_TLS_KEY=/certs/domain.key", REGISTRY_IMAGE})
 		session.WaitWithDefaultTimeout()
-		Expect(session).Should(Exit(0))
+		Expect(session).Should(ExitCleanly())
 
 		if !WaitContainerReady(podmanTest, "registry", "listening on", 20, 1) {
 			Skip("Cannot start docker registry.")
 		}
+
+		// collision protection: each test uses a unique authfile
+		os.Setenv("REGISTRY_AUTH_FILE", filepath.Join(podmanTest.TempDir, "default-auth.json"))
 	})
 
 	AfterEach(func() {
-		podmanTest.Cleanup()
+		os.Unsetenv("REGISTRY_AUTH_FILE")
 		os.RemoveAll(authPath)
 		os.RemoveAll(certDirPath)
 	})
@@ -106,33 +87,42 @@ var _ = Describe("Podman login and logout", func() {
 		var authInfo map[string]interface{}
 		err = json.Unmarshal(authBytes, &authInfo)
 		Expect(err).ToNot(HaveOccurred())
-		fmt.Println(authInfo)
+		GinkgoWriter.Println(authInfo)
 
 		const authsKey = "auths"
 		Expect(authInfo).To(HaveKey(authsKey))
 
 		auths, ok := authInfo[authsKey].(map[string]interface{})
-		Expect(ok).To(BeTrue())
+		Expect(ok).To(BeTrue(), "authInfo[%s]", authsKey)
 
 		return auths
 	}
 
 	It("podman login and logout", func() {
+		authFile := os.Getenv("REGISTRY_AUTH_FILE")
+		Expect(authFile).NotTo(BeEmpty(), "$REGISTRY_AUTH_FILE")
+
 		session := podmanTest.Podman([]string{"login", "-u", "podmantest", "-p", "test", server})
 		session.WaitWithDefaultTimeout()
-		Expect(session).Should(Exit(0))
+		Expect(session).Should(ExitCleanly())
 
-		session = podmanTest.Podman([]string{"push", ALPINE, testImg})
+		// Confirm that file was created, with the desired credentials
+		auths := readAuthInfo(authFile)
+		Expect(auths).To(HaveKey(server))
+		// base64-encoded "podmantest:test"
+		Expect(auths[server]).To(HaveKeyWithValue("auth", "cG9kbWFudGVzdDp0ZXN0"))
+
+		session = podmanTest.Podman([]string{"push", "-q", ALPINE, testImg})
 		session.WaitWithDefaultTimeout()
-		Expect(session).Should(Exit(0))
+		Expect(session).Should(ExitCleanly())
 
 		session = podmanTest.Podman([]string{"logout", server})
 		session.WaitWithDefaultTimeout()
-		Expect(session).Should(Exit(0))
+		Expect(session).Should(ExitCleanly())
 
-		session = podmanTest.Podman([]string{"push", ALPINE, testImg})
+		session = podmanTest.Podman([]string{"push", "-q", ALPINE, testImg})
 		session.WaitWithDefaultTimeout()
-		Expect(session).To(ExitWithError())
+		Expect(session).To(ExitWithError(125, ": authentication required"))
 	})
 
 	It("podman login and logout without registry parameter", func() {
@@ -158,56 +148,128 @@ var _ = Describe("Podman login and logout", func() {
 
 		session := podmanTest.Podman([]string{"login", "-u", "podmantest", "-p", "test"})
 		session.WaitWithDefaultTimeout()
-		Expect(session).Should(Exit(0))
+		Expect(session).Should(ExitCleanly())
 
 		session = podmanTest.Podman([]string{"logout"})
 		session.WaitWithDefaultTimeout()
-		Expect(session).Should(Exit(0))
+		Expect(session).Should(ExitCleanly())
 	})
 
 	It("podman login and logout with flag --authfile", func() {
 		authFile := filepath.Join(podmanTest.TempDir, "auth.json")
 		session := podmanTest.Podman([]string{"login", "--username", "podmantest", "--password", "test", "--authfile", authFile, server})
 		session.WaitWithDefaultTimeout()
-		Expect(session).Should(Exit(0))
+		Expect(session).Should(ExitCleanly())
 
 		readAuthInfo(authFile)
 
 		// push should fail with nonexistent authfile
-		session = podmanTest.Podman([]string{"push", "--authfile", "/tmp/nonexistent", ALPINE, testImg})
+		session = podmanTest.Podman([]string{"push", "-q", "--authfile", "/tmp/nonexistent", ALPINE, testImg})
 		session.WaitWithDefaultTimeout()
-		Expect(session).To(ExitWithError())
+		Expect(session).To(ExitWithError(125, "credential file is not accessible: faccessat /tmp/nonexistent: no such file or directory"))
 
-		session = podmanTest.Podman([]string{"push", "--authfile", authFile, ALPINE, testImg})
+		session = podmanTest.Podman([]string{"push", "-q", "--authfile", authFile, ALPINE, testImg})
 		session.WaitWithDefaultTimeout()
-		Expect(session).Should(Exit(0))
+		Expect(session).Should(ExitCleanly())
 
-		session = podmanTest.Podman([]string{"run", "--authfile", authFile, testImg})
+		session = podmanTest.Podman([]string{"run", "-q", "--authfile", authFile, testImg})
 		session.WaitWithDefaultTimeout()
-		Expect(session).Should(Exit(0))
+		Expect(session).Should(ExitCleanly())
 
 		// logout should fail with nonexistent authfile
 		session = podmanTest.Podman([]string{"logout", "--authfile", "/tmp/nonexistent", server})
 		session.WaitWithDefaultTimeout()
-		Expect(session).To(ExitWithError())
+		Expect(session).To(ExitWithError(125, "credential file is not accessible: faccessat /tmp/nonexistent: no such file or directory"))
 
 		session = podmanTest.Podman([]string{"logout", "--authfile", authFile, server})
 		session.WaitWithDefaultTimeout()
-		Expect(session).Should(Exit(0))
+		Expect(session).Should(ExitCleanly())
+	})
+
+	It("podman login and logout --compat-auth-file flag handling", func() {
+		// A minimal smoke test
+		compatAuthFile := filepath.Join(podmanTest.TempDir, "config.json")
+		session := podmanTest.Podman([]string{"login", "--username", "podmantest", "--password", "test", "--compat-auth-file", compatAuthFile, server})
+		session.WaitWithDefaultTimeout()
+		Expect(session).Should(ExitCleanly())
+
+		readAuthInfo(compatAuthFile)
+
+		session = podmanTest.Podman([]string{"logout", "--compat-auth-file", compatAuthFile, server})
+		session.WaitWithDefaultTimeout()
+		Expect(session).Should(ExitCleanly())
+
+		// logout should fail with nonexistent authfile
+		session = podmanTest.Podman([]string{"logout", "--compat-auth-file", "/tmp/nonexistent", server})
+		session.WaitWithDefaultTimeout()
+		Expect(session).To(ExitWithError(125, "credential file is not accessible: faccessat /tmp/nonexistent: no such file or directory"))
+
+		// inconsistent command line flags are rejected
+		// Pre-create the files to make sure we are not hitting the “file not found” path
+		authFile := filepath.Join(podmanTest.TempDir, "auth.json")
+		err := os.WriteFile(authFile, []byte("{}"), 0o700)
+		Expect(err).ToNot(HaveOccurred())
+		err = os.WriteFile(compatAuthFile, []byte("{}"), 0o700)
+		Expect(err).ToNot(HaveOccurred())
+
+		session = podmanTest.Podman([]string{"login", "--username", "podmantest", "--password", "test",
+			"--authfile", authFile, "--compat-auth-file", compatAuthFile, server})
+		session.WaitWithDefaultTimeout()
+		Expect(session).To(ExitWithError(125, "options for paths to the credential file and to the Docker-compatible credential file can not be set simultaneously"))
+
+		session = podmanTest.Podman([]string{"logout", "--authfile", authFile, "--compat-auth-file", compatAuthFile, server})
+		session.WaitWithDefaultTimeout()
+		Expect(session).To(ExitWithError(125, "options for paths to the credential file and to the Docker-compatible credential file can not be set simultaneously"))
+	})
+
+	It("podman manifest with --authfile", func() {
+		os.Unsetenv("REGISTRY_AUTH_FILE")
+
+		authFile := filepath.Join(podmanTest.TempDir, "auth.json")
+		session := podmanTest.Podman([]string{"login", "--username", "podmantest", "--password", "test", "--authfile", authFile, server})
+		session.WaitWithDefaultTimeout()
+		Expect(session).Should(ExitCleanly())
+
+		readAuthInfo(authFile)
+
+		session = podmanTest.Podman([]string{"manifest", "create", testImg})
+		session.WaitWithDefaultTimeout()
+		Expect(session).Should(ExitCleanly())
+
+		session = podmanTest.Podman([]string{"manifest", "push", "-q", testImg})
+		session.WaitWithDefaultTimeout()
+		Expect(session).To(ExitWithError(125, ": authentication required"))
+
+		session = podmanTest.Podman([]string{"manifest", "push", "-q", "--authfile", authFile, testImg})
+		session.WaitWithDefaultTimeout()
+		Expect(session).Should(ExitCleanly())
+
+		// Now remove the local manifest to trigger remote inspection
+		session = podmanTest.Podman([]string{"manifest", "rm", testImg})
+		session.WaitWithDefaultTimeout()
+		Expect(session).Should(ExitCleanly())
+
+		session = podmanTest.Podman([]string{"manifest", "inspect", testImg})
+		session.WaitWithDefaultTimeout()
+		Expect(session).To(ExitWithError(125, ": authentication required"))
+
+		session = podmanTest.Podman([]string{"manifest", "inspect", "--authfile", authFile, testImg})
+		session.WaitWithDefaultTimeout()
+		Expect(session).Should(ExitCleanly())
 	})
 
 	It("podman login and logout with --tls-verify", func() {
 		session := podmanTest.Podman([]string{"login", "--username", "podmantest", "--password", "test", "--tls-verify=false", server})
 		session.WaitWithDefaultTimeout()
-		Expect(session).Should(Exit(0))
+		Expect(session).Should(ExitCleanly())
 
-		session = podmanTest.Podman([]string{"push", ALPINE, testImg})
+		session = podmanTest.Podman([]string{"push", "-q", ALPINE, testImg})
 		session.WaitWithDefaultTimeout()
-		Expect(session).Should(Exit(0))
+		Expect(session).Should(ExitCleanly())
 
 		session = podmanTest.Podman([]string{"logout", server})
 		session.WaitWithDefaultTimeout()
-		Expect(session).Should(Exit(0))
+		Expect(session).Should(ExitCleanly())
 	})
 	It("podman login and logout with --cert-dir", func() {
 		certDir := filepath.Join(podmanTest.TempDir, "certs")
@@ -219,15 +281,15 @@ var _ = Describe("Podman login and logout", func() {
 
 		session := podmanTest.Podman([]string{"login", "--username", "podmantest", "--password", "test", "--cert-dir", certDir, server})
 		session.WaitWithDefaultTimeout()
-		Expect(session).Should(Exit(0))
+		Expect(session).Should(ExitCleanly())
 
-		session = podmanTest.Podman([]string{"push", "--cert-dir", certDir, ALPINE, testImg})
+		session = podmanTest.Podman([]string{"push", "-q", "--cert-dir", certDir, ALPINE, testImg})
 		session.WaitWithDefaultTimeout()
-		Expect(session).Should(Exit(0))
+		Expect(session).Should(ExitCleanly())
 
 		session = podmanTest.Podman([]string{"logout", server})
 		session.WaitWithDefaultTimeout()
-		Expect(session).Should(Exit(0))
+		Expect(session).Should(ExitCleanly())
 	})
 	It("podman login and logout with multi registry", func() {
 		certDir := filepath.Join(os.Getenv("HOME"), ".config/containers/certs.d", "localhost:9001")
@@ -250,7 +312,7 @@ var _ = Describe("Podman login and logout", func() {
 			"-v", strings.Join([]string{certPath, "/certs:z"}, ":"), "-e", "REGISTRY_HTTP_TLS_CERTIFICATE=/certs/domain.crt",
 			"-e", "REGISTRY_HTTP_TLS_KEY=/certs/domain.key", REGISTRY_IMAGE})
 		session.WaitWithDefaultTimeout()
-		Expect(session).Should(Exit(0))
+		Expect(session).Should(ExitCleanly())
 
 		if !WaitContainerReady(podmanTest, "registry1", "listening on", 20, 1) {
 			Skip("Cannot start docker registry.")
@@ -258,55 +320,55 @@ var _ = Describe("Podman login and logout", func() {
 
 		session = podmanTest.Podman([]string{"login", "--username", "podmantest", "--password", "test", server})
 		session.WaitWithDefaultTimeout()
-		Expect(session).Should(Exit(0))
+		Expect(session).Should(ExitCleanly())
 
-		session = podmanTest.Podman([]string{"push", ALPINE, testImg})
+		session = podmanTest.Podman([]string{"push", "-q", ALPINE, testImg})
 		session.WaitWithDefaultTimeout()
-		Expect(session).Should(Exit(0))
+		Expect(session).Should(ExitCleanly())
 
-		session = podmanTest.Podman([]string{"push", ALPINE, "localhost:9001/test-alpine"})
+		session = podmanTest.Podman([]string{"push", "-q", ALPINE, "localhost:9001/test-alpine"})
 		session.WaitWithDefaultTimeout()
-		Expect(session).To(ExitWithError())
+		Expect(session).To(ExitWithError(125, "/test-alpine: authentication required"))
 
 		session = podmanTest.Podman([]string{"login", "--username", "podmantest", "--password", "test", "localhost:9001"})
 		session.WaitWithDefaultTimeout()
-		Expect(session).Should(Exit(0))
+		Expect(session).Should(ExitCleanly())
 
-		session = podmanTest.Podman([]string{"push", ALPINE, testImg})
+		session = podmanTest.Podman([]string{"push", "-q", ALPINE, testImg})
 		session.WaitWithDefaultTimeout()
-		Expect(session).Should(Exit(0))
+		Expect(session).Should(ExitCleanly())
 
-		session = podmanTest.Podman([]string{"push", ALPINE, "localhost:9001/test-alpine"})
+		session = podmanTest.Podman([]string{"push", "-q", ALPINE, "localhost:9001/test-alpine"})
 		session.WaitWithDefaultTimeout()
-		Expect(session).Should(Exit(0))
+		Expect(session).Should(ExitCleanly())
 
 		session = podmanTest.Podman([]string{"logout", server})
 		session.WaitWithDefaultTimeout()
-		Expect(session).Should(Exit(0))
+		Expect(session).Should(ExitCleanly())
 
-		session = podmanTest.Podman([]string{"push", ALPINE, testImg})
+		session = podmanTest.Podman([]string{"push", "-q", ALPINE, testImg})
 		session.WaitWithDefaultTimeout()
-		Expect(session).To(ExitWithError())
+		Expect(session).To(ExitWithError(125, "/test-alpine: authentication required"))
 
-		session = podmanTest.Podman([]string{"push", ALPINE, "localhost:9001/test-alpine"})
+		session = podmanTest.Podman([]string{"push", "-q", ALPINE, "localhost:9001/test-alpine"})
 		session.WaitWithDefaultTimeout()
-		Expect(session).Should(Exit(0))
+		Expect(session).Should(ExitCleanly())
 
 		session = podmanTest.Podman([]string{"login", "--username", "podmantest", "--password", "test", "localhost:9001"})
 		session.WaitWithDefaultTimeout()
-		Expect(session).Should(Exit(0))
+		Expect(session).Should(ExitCleanly())
 
 		session = podmanTest.Podman([]string{"logout", "-a"})
 		session.WaitWithDefaultTimeout()
-		Expect(session).Should(Exit(0))
+		Expect(session).Should(ExitCleanly())
 
-		session = podmanTest.Podman([]string{"push", ALPINE, testImg})
+		session = podmanTest.Podman([]string{"push", "-q", ALPINE, testImg})
 		session.WaitWithDefaultTimeout()
-		Expect(session).To(ExitWithError())
+		Expect(session).To(ExitWithError(125, "/test-alpine: authentication required"))
 
-		session = podmanTest.Podman([]string{"push", ALPINE, "localhost:9001/test-alpine"})
+		session = podmanTest.Podman([]string{"push", "-q", ALPINE, "localhost:9001/test-alpine"})
 		session.WaitWithDefaultTimeout()
-		Expect(session).To(ExitWithError())
+		Expect(session).To(ExitWithError(125, "/test-alpine: authentication required"))
 	})
 
 	It("podman login and logout with repository", func() {
@@ -321,7 +383,7 @@ var _ = Describe("Podman login and logout", func() {
 			testRepository,
 		})
 		session.WaitWithDefaultTimeout()
-		Expect(session).Should(Exit(0))
+		Expect(session).Should(ExitCleanly())
 
 		authInfo := readAuthInfo(authFile)
 		Expect(authInfo).To(HaveKey(testRepository))
@@ -332,7 +394,7 @@ var _ = Describe("Podman login and logout", func() {
 			testRepository,
 		})
 		session.WaitWithDefaultTimeout()
-		Expect(session).Should(Exit(0))
+		Expect(session).Should(ExitCleanly())
 
 		authInfo = readAuthInfo(authFile)
 		Expect(authInfo).NotTo(HaveKey(testRepository))
@@ -350,18 +412,18 @@ var _ = Describe("Podman login and logout", func() {
 			testTarget,
 		})
 		session.WaitWithDefaultTimeout()
-		Expect(session).Should(Exit(0))
+		Expect(session).Should(ExitCleanly())
 
 		authInfo := readAuthInfo(authFile)
 		Expect(authInfo).To(HaveKey(testTarget))
 
 		session = podmanTest.Podman([]string{
-			"push",
+			"push", "-q",
 			"--authfile", authFile,
 			ALPINE, testTarget,
 		})
 		session.WaitWithDefaultTimeout()
-		Expect(session).Should(Exit(0))
+		Expect(session).Should(ExitCleanly())
 
 	})
 
@@ -381,7 +443,7 @@ var _ = Describe("Podman login and logout", func() {
 				testRepo,
 			})
 			session.WaitWithDefaultTimeout()
-			Expect(session).Should(Exit(0))
+			Expect(session).Should(ExitCleanly())
 		}
 
 		authInfo := readAuthInfo(authFile)
@@ -389,12 +451,12 @@ var _ = Describe("Podman login and logout", func() {
 		Expect(authInfo).To(HaveKey(testRepos[1]))
 
 		session := podmanTest.Podman([]string{
-			"push",
+			"push", "-q",
 			"--authfile", authFile,
 			ALPINE, testRepos[0] + "/test-image-alpine",
 		})
 		session.WaitWithDefaultTimeout()
-		Expect(session).Should(Exit(0))
+		Expect(session).Should(ExitCleanly())
 
 		session = podmanTest.Podman([]string{
 			"logout",
@@ -402,15 +464,15 @@ var _ = Describe("Podman login and logout", func() {
 			testRepos[0],
 		})
 		session.WaitWithDefaultTimeout()
-		Expect(session).Should(Exit(0))
+		Expect(session).Should(ExitCleanly())
 
 		session = podmanTest.Podman([]string{
-			"push",
+			"push", "-q",
 			"--authfile", authFile,
 			ALPINE, testRepos[0] + "/test-image-alpine",
 		})
 		session.WaitWithDefaultTimeout()
-		Expect(session).Should(Exit(0))
+		Expect(session).Should(ExitCleanly())
 
 		session = podmanTest.Podman([]string{
 			"logout",
@@ -418,7 +480,7 @@ var _ = Describe("Podman login and logout", func() {
 			testRepos[1],
 		})
 		session.WaitWithDefaultTimeout()
-		Expect(session).Should(Exit(0))
+		Expect(session).Should(ExitCleanly())
 
 		authInfo = readAuthInfo(authFile)
 		Expect(authInfo).NotTo(HaveKey(testRepos[0]))
@@ -440,7 +502,7 @@ var _ = Describe("Podman login and logout", func() {
 				invalidArg,
 			})
 			session.WaitWithDefaultTimeout()
-			Expect(session).To(Exit(0))
+			Expect(session).To(ExitCleanly())
 		}
 	})
 
@@ -454,20 +516,20 @@ var _ = Describe("Podman login and logout", func() {
 		Expect(err).ToNot(HaveOccurred())
 
 		session := podmanTest.Podman([]string{
-			"push",
+			"push", "-q",
 			"--authfile", authFile,
 			ALPINE, server + "/podmantest/test-image",
 		})
 		session.WaitWithDefaultTimeout()
-		Expect(session).To(ExitWithError())
+		Expect(session).To(ExitWithError(125, "/test-image: authentication required"))
 
 		session = podmanTest.Podman([]string{
-			"push",
+			"push", "-q",
 			"--authfile", authFile,
 			ALPINE, server + "/test-image",
 		})
 		session.WaitWithDefaultTimeout()
-		Expect(session).To(Exit(0))
+		Expect(session).To(ExitCleanly())
 	})
 
 	It("podman login and logout with repository pull with wrong auth.json credentials", func() {
@@ -482,15 +544,15 @@ var _ = Describe("Podman login and logout", func() {
 			testTarget,
 		})
 		session.WaitWithDefaultTimeout()
-		Expect(session).Should(Exit(0))
+		Expect(session).Should(ExitCleanly())
 
 		session = podmanTest.Podman([]string{
-			"push",
+			"push", "-q",
 			"--authfile", authFile,
 			ALPINE, testTarget,
 		})
 		session.WaitWithDefaultTimeout()
-		Expect(session).Should(Exit(0))
+		Expect(session).Should(ExitCleanly())
 
 		// only `server + /podmantest` and `server` have the correct login data
 		err := os.WriteFile(authFile, []byte(fmt.Sprintf(`{"auths": {
@@ -501,11 +563,11 @@ var _ = Describe("Podman login and logout", func() {
 		Expect(err).ToNot(HaveOccurred())
 
 		session = podmanTest.Podman([]string{
-			"pull",
+			"pull", "-q",
 			"--authfile", authFile,
 			server + "/podmantest/test-alpine",
 		})
 		session.WaitWithDefaultTimeout()
-		Expect(session).To(ExitWithError())
+		Expect(session).To(ExitWithError(125, "/test-alpine: authentication required"))
 	})
 })
