@@ -5,9 +5,9 @@ import (
 	"os"
 	"path/filepath"
 
+	. "github.com/containers/podman/v5/test/utils"
 	. "github.com/onsi/ginkgo/v2"
 	. "github.com/onsi/gomega"
-	. "github.com/onsi/gomega/gexec"
 )
 
 var pruneImage = fmt.Sprintf(`
@@ -26,20 +26,18 @@ var _ = Describe("Podman prune", func() {
 	It("podman container prune containers", func() {
 		top := podmanTest.RunTopContainer("")
 		top.WaitWithDefaultTimeout()
-		Expect(top).Should(Exit(0))
+		Expect(top).Should(ExitCleanly())
 
 		top = podmanTest.RunTopContainer("")
 		top.WaitWithDefaultTimeout()
-		Expect(top).Should(Exit(0))
+		Expect(top).Should(ExitCleanly())
 		cid := top.OutputToString()
 
-		stop := podmanTest.Podman([]string{"stop", cid})
-		stop.WaitWithDefaultTimeout()
-		Expect(stop).Should(Exit(0))
+		podmanTest.StopContainer(cid)
 
 		prune := podmanTest.Podman([]string{"container", "prune", "-f"})
 		prune.WaitWithDefaultTimeout()
-		Expect(prune).Should(Exit(0))
+		Expect(prune).Should(ExitCleanly())
 
 		Expect(podmanTest.NumberOfContainers()).To(Equal(1))
 	})
@@ -47,11 +45,11 @@ var _ = Describe("Podman prune", func() {
 	It("podman container prune after create containers", func() {
 		create := podmanTest.Podman([]string{"create", "--name", "test", BB})
 		create.WaitWithDefaultTimeout()
-		Expect(create).Should(Exit(0))
+		Expect(create).Should(ExitCleanly())
 
 		prune := podmanTest.Podman([]string{"container", "prune", "-f"})
 		prune.WaitWithDefaultTimeout()
-		Expect(prune).Should(Exit(0))
+		Expect(prune).Should(ExitCleanly())
 
 		Expect(podmanTest.NumberOfContainers()).To(Equal(0))
 	})
@@ -59,15 +57,15 @@ var _ = Describe("Podman prune", func() {
 	It("podman container prune after create & init containers", func() {
 		create := podmanTest.Podman([]string{"create", "--name", "test", BB})
 		create.WaitWithDefaultTimeout()
-		Expect(create).Should(Exit(0))
+		Expect(create).Should(ExitCleanly())
 
 		init := podmanTest.Podman([]string{"init", "test"})
 		init.WaitWithDefaultTimeout()
-		Expect(init).Should(Exit(0))
+		Expect(init).Should(ExitCleanly())
 
 		prune := podmanTest.Podman([]string{"container", "prune", "-f"})
 		prune.WaitWithDefaultTimeout()
-		Expect(prune).Should(Exit(0))
+		Expect(prune).Should(ExitCleanly())
 
 		Expect(podmanTest.NumberOfContainers()).To(Equal(0))
 	})
@@ -75,21 +73,21 @@ var _ = Describe("Podman prune", func() {
 	It("podman image prune - remove only dangling images", func() {
 		session := podmanTest.Podman([]string{"images", "-a"})
 		session.WaitWithDefaultTimeout()
-		Expect(session).Should(Exit(0))
+		Expect(session).Should(ExitCleanly())
 		Expect(session.OutputToString()).To(Not(ContainSubstring("<none>")))
 		numImages := len(session.OutputToStringArray())
 
 		// Since there's no dangling image, none should be removed.
 		session = podmanTest.Podman([]string{"image", "prune", "-f"})
 		session.WaitWithDefaultTimeout()
-		Expect(session).Should(Exit(0))
+		Expect(session).Should(ExitCleanly())
 		Expect(session.OutputToStringArray()).To(BeEmpty())
 
 		// Let's be extra sure that the same number of images is
 		// reported.
 		session = podmanTest.Podman([]string{"images", "-a"})
 		session.WaitWithDefaultTimeout()
-		Expect(session).Should(Exit(0))
+		Expect(session).Should(ExitCleanly())
 		Expect(session.OutputToStringArray()).To(HaveLen(numImages))
 
 		// Now build an image and untag it.  The (intermediate) images
@@ -97,11 +95,11 @@ var _ = Describe("Podman prune", func() {
 		podmanTest.BuildImage(pruneImage, "alpine_bash:latest", "true")
 		session = podmanTest.Podman([]string{"untag", "alpine_bash:latest"})
 		session.WaitWithDefaultTimeout()
-		Expect(session).Should(Exit(0))
+		Expect(session).Should(ExitCleanly())
 
 		session = podmanTest.Podman([]string{"images", "-a"})
 		session.WaitWithDefaultTimeout()
-		Expect(session).Should(Exit(0))
+		Expect(session).Should(ExitCleanly())
 		Expect(session.OutputToString()).To(ContainSubstring("<none>"))
 		numImages = len(session.OutputToStringArray())
 
@@ -109,7 +107,7 @@ var _ = Describe("Podman prune", func() {
 		// remove them.
 		session = podmanTest.Podman([]string{"image", "prune", "-f"})
 		session.WaitWithDefaultTimeout()
-		Expect(session).Should(Exit(0))
+		Expect(session).Should(ExitCleanly())
 		numPrunedImages := len(session.OutputToStringArray())
 		Expect(numPrunedImages).To(BeNumerically(">=", 1), "numPrunedImages")
 
@@ -117,7 +115,7 @@ var _ = Describe("Podman prune", func() {
 		// been removed.
 		session = podmanTest.Podman([]string{"images", "-a"})
 		session.WaitWithDefaultTimeout()
-		Expect(session).Should(Exit(0))
+		Expect(session).Should(ExitCleanly())
 		Expect(session.OutputToStringArray()).To(HaveLen(numImages - numPrunedImages))
 	})
 
@@ -128,24 +126,24 @@ var _ = Describe("Podman prune", func() {
 
 		session := podmanTest.Podman([]string{"images", "-a"})
 		session.WaitWithDefaultTimeout()
-		Expect(session).Should(Exit(0))
+		Expect(session).Should(ExitCleanly())
 		Expect(session.OutputToString()).To(ContainSubstring("<none>"))
 
 		// Nothing will be pruned.
 		session = podmanTest.Podman([]string{"image", "prune", "-f"})
 		session.WaitWithDefaultTimeout()
-		Expect(session).Should(Exit(0))
+		Expect(session).Should(ExitCleanly())
 		Expect(session.OutputToStringArray()).To(BeEmpty())
 
 		// Now the image will be untagged, and its parent images will
 		// be removed recursively.
 		session = podmanTest.Podman([]string{"untag", "empty:scratch"})
 		session.WaitWithDefaultTimeout()
-		Expect(session).Should(Exit(0))
+		Expect(session).Should(ExitCleanly())
 
 		session = podmanTest.Podman([]string{"image", "prune", "-f"})
 		session.WaitWithDefaultTimeout()
-		Expect(session).Should(Exit(0))
+		Expect(session).Should(ExitCleanly())
 		Expect(session.OutputToStringArray()).To(HaveLen(2))
 	})
 
@@ -154,18 +152,18 @@ var _ = Describe("Podman prune", func() {
 		podmanTest.BuildImage(pruneImage, "alpine_bash:latest", "true")
 		none := podmanTest.Podman([]string{"images", "-a"})
 		none.WaitWithDefaultTimeout()
-		Expect(none).Should(Exit(0))
+		Expect(none).Should(ExitCleanly())
 		hasNone, result := none.GrepString("<none>")
 		Expect(result).To(HaveLen(2))
 		Expect(hasNone).To(BeTrue())
 
 		prune := podmanTest.Podman([]string{"image", "prune", "-f"})
 		prune.WaitWithDefaultTimeout()
-		Expect(prune).Should(Exit(0))
+		Expect(prune).Should(ExitCleanly())
 
 		after := podmanTest.Podman([]string{"images", "-a"})
 		after.WaitWithDefaultTimeout()
-		Expect(after).Should(Exit(0))
+		Expect(after).Should(ExitCleanly())
 		hasNoneAfter, result := after.GrepString("<none>")
 		Expect(hasNoneAfter).To(BeTrue())
 		Expect(len(after.OutputToStringArray())).To(BeNumerically(">", 1))
@@ -178,15 +176,15 @@ var _ = Describe("Podman prune", func() {
 
 		images := podmanTest.Podman([]string{"images", "-a"})
 		images.WaitWithDefaultTimeout()
-		Expect(images).Should(Exit(0))
+		Expect(images).Should(ExitCleanly())
 
 		prune := podmanTest.Podman([]string{"image", "prune", "-af"})
 		prune.WaitWithDefaultTimeout()
-		Expect(prune).Should(Exit(0))
+		Expect(prune).Should(ExitCleanly())
 
 		images = podmanTest.Podman([]string{"images", "-aq"})
 		images.WaitWithDefaultTimeout()
-		Expect(images).Should(Exit(0))
+		Expect(images).Should(ExitCleanly())
 		// all images are unused, so they all should be deleted!
 		Expect(images.OutputToStringArray()).To(HaveLen(len(CACHE_IMAGES)))
 	})
@@ -197,7 +195,7 @@ var _ = Describe("Podman prune", func() {
 		podmanTest.BuildImage(pruneImage, "alpine_bash:latest", "true")
 		prune := podmanTest.Podman([]string{"system", "prune", "-a", "--force"})
 		prune.WaitWithDefaultTimeout()
-		Expect(prune).Should(Exit(0))
+		Expect(prune).Should(ExitCleanly())
 
 		images := podmanTest.Podman([]string{"images", "-aq"})
 		images.WaitWithDefaultTimeout()
@@ -209,33 +207,30 @@ var _ = Describe("Podman prune", func() {
 		useCustomNetworkDir(podmanTest, tempdir)
 		session := podmanTest.Podman([]string{"pod", "create"})
 		session.WaitWithDefaultTimeout()
-		Expect(session).Should(Exit(0))
+		Expect(session).Should(ExitCleanly())
 
 		session = podmanTest.Podman([]string{"pod", "create"})
 		session.WaitWithDefaultTimeout()
-		Expect(session).Should(Exit(0))
+		Expect(session).Should(ExitCleanly())
 		podid1 := session.OutputToString()
 
 		session = podmanTest.Podman([]string{"pod", "start", podid1})
 		session.WaitWithDefaultTimeout()
-		Expect(session).Should(Exit(0))
-
-		session = podmanTest.Podman([]string{"pod", "stop", podid1})
-		session.WaitWithDefaultTimeout()
-		Expect(session).Should(Exit(0))
+		Expect(session).Should(ExitCleanly())
+		podmanTest.StopPod(podid1)
 
 		pods := podmanTest.Podman([]string{"pod", "ps"})
 		pods.WaitWithDefaultTimeout()
-		Expect(pods).Should(Exit(0))
+		Expect(pods).Should(ExitCleanly())
 		Expect(pods.OutputToStringArray()).To(HaveLen(3))
 
 		prune := podmanTest.Podman([]string{"system", "prune", "-f"})
 		prune.WaitWithDefaultTimeout()
-		Expect(prune).Should(Exit(0))
+		Expect(prune).Should(ExitCleanly())
 
 		pods = podmanTest.Podman([]string{"pod", "ps"})
 		pods.WaitWithDefaultTimeout()
-		Expect(pods).Should(Exit(0))
+		Expect(pods).Should(ExitCleanly())
 		Expect(pods.OutputToStringArray()).To(HaveLen(2))
 	})
 
@@ -244,40 +239,40 @@ var _ = Describe("Podman prune", func() {
 		// Create new network.
 		session := podmanTest.Podman([]string{"network", "create", "test"})
 		session.WaitWithDefaultTimeout()
-		Expect(session).Should(Exit(0))
+		Expect(session).Should(ExitCleanly())
 
 		// Remove all unused networks.
 		session = podmanTest.Podman([]string{"system", "prune", "-f"})
 		session.WaitWithDefaultTimeout()
-		Expect(session).Should(Exit(0))
+		Expect(session).Should(ExitCleanly())
 
 		// Default network should exists.
 		session = podmanTest.Podman([]string{"network", "ls", "-q", "--filter", "name=^podman$"})
 		session.WaitWithDefaultTimeout()
-		Expect(session).Should(Exit(0))
+		Expect(session).Should(ExitCleanly())
 		Expect(session.OutputToStringArray()).To(HaveLen(1))
 
 		// Unused networks removed.
 		session = podmanTest.Podman([]string{"network", "ls", "-q", "--filter", "name=^test$"})
 		session.WaitWithDefaultTimeout()
-		Expect(session).Should(Exit(0))
+		Expect(session).Should(ExitCleanly())
 		Expect(session.OutputToStringArray()).To(BeEmpty())
 
 		// Create new network.
 		session = podmanTest.Podman([]string{"network", "create", "test1", "--label", "foo"})
 		session.WaitWithDefaultTimeout()
-		Expect(session).Should(Exit(0))
+		Expect(session).Should(ExitCleanly())
 
 		// Remove all unused networks.
 		session = podmanTest.Podman([]string{"system", "prune", "-f", "--filter", "label!=foo"})
 		session.WaitWithDefaultTimeout()
-		Expect(session).Should(Exit(0))
+		Expect(session).Should(ExitCleanly())
 		Expect(session.OutputToString()).Should(Equal("Total reclaimed space: 0B"))
 
 		// Unused networks removed.
 		session = podmanTest.Podman([]string{"network", "ls", "-q", "--filter", "name=^test1$"})
 		session.WaitWithDefaultTimeout()
-		Expect(session).Should(Exit(0))
+		Expect(session).Should(ExitCleanly())
 		// label should make sure we do not remove this network
 		Expect(session.OutputToStringArray()).To(HaveLen(1))
 	})
@@ -286,30 +281,27 @@ var _ = Describe("Podman prune", func() {
 		useCustomNetworkDir(podmanTest, tempdir)
 		session := podmanTest.Podman([]string{"pod", "create"})
 		session.WaitWithDefaultTimeout()
-		Expect(session).Should(Exit(0))
+		Expect(session).Should(ExitCleanly())
 		podid1 := session.OutputToString()
 
 		// Start and stop a pod to get it in exited state.
 		session = podmanTest.Podman([]string{"pod", "start", podid1})
 		session.WaitWithDefaultTimeout()
-		Expect(session).Should(Exit(0))
-
-		session = podmanTest.Podman([]string{"pod", "stop", podid1})
-		session.WaitWithDefaultTimeout()
-		Expect(session).Should(Exit(0))
+		Expect(session).Should(ExitCleanly())
+		podmanTest.StopPod(podid1)
 
 		// Create a container. This container should be pruned.
 		create := podmanTest.Podman([]string{"create", "--name", "test", BB})
 		create.WaitWithDefaultTimeout()
-		Expect(create).Should(Exit(0))
+		Expect(create).Should(ExitCleanly())
 
 		prune := podmanTest.Podman([]string{"system", "prune", "-f"})
 		prune.WaitWithDefaultTimeout()
-		Expect(prune).Should(Exit(0))
+		Expect(prune).Should(ExitCleanly())
 
 		pods := podmanTest.Podman([]string{"pod", "ps"})
 		pods.WaitWithDefaultTimeout()
-		Expect(pods).Should(Exit(0))
+		Expect(pods).Should(ExitCleanly())
 		Expect(podmanTest.NumberOfPods()).To(Equal(0))
 
 		Expect(podmanTest.NumberOfContainers()).To(Equal(0))
@@ -320,26 +312,23 @@ var _ = Describe("Podman prune", func() {
 		// Start and stop a pod to get it in exited state.
 		session := podmanTest.Podman([]string{"pod", "create"})
 		session.WaitWithDefaultTimeout()
-		Expect(session).Should(Exit(0))
+		Expect(session).Should(ExitCleanly())
 		podid1 := session.OutputToString()
 
 		session = podmanTest.Podman([]string{"pod", "start", podid1})
 		session.WaitWithDefaultTimeout()
-		Expect(session).Should(Exit(0))
-
-		session = podmanTest.Podman([]string{"pod", "stop", podid1})
-		session.WaitWithDefaultTimeout()
-		Expect(session).Should(Exit(0))
+		Expect(session).Should(ExitCleanly())
+		podmanTest.StopPod(podid1)
 
 		// Start a pod and leave it running
 		session = podmanTest.Podman([]string{"pod", "create"})
 		session.WaitWithDefaultTimeout()
-		Expect(session).Should(Exit(0))
+		Expect(session).Should(ExitCleanly())
 		podid2 := session.OutputToString()
 
 		session = podmanTest.Podman([]string{"pod", "start", podid2})
 		session.WaitWithDefaultTimeout()
-		Expect(session).Should(Exit(0))
+		Expect(session).Should(ExitCleanly())
 
 		// Number of pod should be 2. One exited one running.
 		Expect(podmanTest.NumberOfPods()).To(Equal(2))
@@ -360,25 +349,25 @@ var _ = Describe("Podman prune", func() {
 		// Adding unused volume should be pruned
 		session = podmanTest.Podman([]string{"volume", "create"})
 		session.WaitWithDefaultTimeout()
-		Expect(session).Should(Exit(0))
+		Expect(session).Should(ExitCleanly())
 
 		session = podmanTest.Podman([]string{"create", "-v", "myvol:/myvol", ALPINE, "ls"})
 		session.WaitWithDefaultTimeout()
-		Expect(session).Should(Exit(0))
+		Expect(session).Should(ExitCleanly())
 
 		session = podmanTest.Podman([]string{"volume", "ls"})
 		session.WaitWithDefaultTimeout()
-		Expect(session).Should(Exit(0))
+		Expect(session).Should(ExitCleanly())
 		Expect(session.OutputToStringArray()).To(HaveLen(3))
 
 		session = podmanTest.Podman([]string{"system", "prune", "--force", "--volumes"})
 		session.WaitWithDefaultTimeout()
-		Expect(session).Should(Exit(0))
+		Expect(session).Should(ExitCleanly())
 
 		// Volumes should be pruned.
 		session = podmanTest.Podman([]string{"volume", "ls"})
 		session.WaitWithDefaultTimeout()
-		Expect(session).Should(Exit(0))
+		Expect(session).Should(ExitCleanly())
 		Expect(session.OutputToStringArray()).To(BeEmpty())
 
 		// One Pod should not be pruned as it was running
@@ -397,35 +386,33 @@ var _ = Describe("Podman prune", func() {
 		useCustomNetworkDir(podmanTest, tempdir)
 		session := podmanTest.Podman([]string{"pod", "create"})
 		session.WaitWithDefaultTimeout()
-		Expect(session).Should(Exit(0))
+		Expect(session).Should(ExitCleanly())
 		podid1 := session.OutputToString()
 
 		// Start and stop a pod to get it in exited state.
 		session = podmanTest.Podman([]string{"pod", "start", podid1})
 		session.WaitWithDefaultTimeout()
-		Expect(session).Should(Exit(0))
+		Expect(session).Should(ExitCleanly())
 
-		session = podmanTest.Podman([]string{"pod", "stop", podid1})
-		session.WaitWithDefaultTimeout()
-		Expect(session).Should(Exit(0))
+		podmanTest.StopPod(podid1)
 
 		// Create a container. This container should be pruned.
 		create := podmanTest.Podman([]string{"create", "--name", "test", BB})
 		create.WaitWithDefaultTimeout()
-		Expect(create).Should(Exit(0))
+		Expect(create).Should(ExitCleanly())
 
 		// Adding unused volume should not be pruned as volumes not set
 		session = podmanTest.Podman([]string{"volume", "create"})
 		session.WaitWithDefaultTimeout()
-		Expect(session).Should(Exit(0))
+		Expect(session).Should(ExitCleanly())
 
 		prune := podmanTest.Podman([]string{"system", "prune", "-f", "-a"})
 		prune.WaitWithDefaultTimeout()
-		Expect(prune).Should(Exit(0))
+		Expect(prune).Should(ExitCleanly())
 
 		pods := podmanTest.Podman([]string{"pod", "ps"})
 		pods.WaitWithDefaultTimeout()
-		Expect(pods).Should(Exit(0))
+		Expect(pods).Should(ExitCleanly())
 		Expect(podmanTest.NumberOfPods()).To(Equal(0))
 
 		Expect(podmanTest.NumberOfContainers()).To(Equal(0))
@@ -433,7 +420,7 @@ var _ = Describe("Podman prune", func() {
 		// Volumes should not be pruned
 		session = podmanTest.Podman([]string{"volume", "ls"})
 		session.WaitWithDefaultTimeout()
-		Expect(session).Should(Exit(0))
+		Expect(session).Should(ExitCleanly())
 		Expect(session.OutputToStringArray()).To(HaveLen(2))
 
 		images := podmanTest.Podman([]string{"images", "-aq"})
@@ -446,66 +433,65 @@ var _ = Describe("Podman prune", func() {
 		useCustomNetworkDir(podmanTest, tempdir)
 		session := podmanTest.Podman([]string{"volume", "create", "--label", "label1=value1", "myvol1"})
 		session.WaitWithDefaultTimeout()
-		Expect(session).Should(Exit(0))
+		Expect(session).Should(ExitCleanly())
 
 		session = podmanTest.Podman([]string{"volume", "create", "--label", "sharedlabel1=slv1", "myvol2"})
 		session.WaitWithDefaultTimeout()
-		Expect(session).Should(Exit(0))
+		Expect(session).Should(ExitCleanly())
 
 		session = podmanTest.Podman([]string{"volume", "create", "--label", "sharedlabel1=slv2", "myvol3"})
 		session.WaitWithDefaultTimeout()
-		Expect(session).Should(Exit(0))
+		Expect(session).Should(ExitCleanly())
 
 		session = podmanTest.Podman([]string{"volume", "create", "--label", "sharedlabel1", "myvol4"})
 		session.WaitWithDefaultTimeout()
-		Expect(session).Should(Exit(0))
+		Expect(session).Should(ExitCleanly())
 
 		session = podmanTest.Podman([]string{"create", "-v", "myvol5:/myvol5", ALPINE, "ls"})
 		session.WaitWithDefaultTimeout()
-		Expect(session).Should(Exit(0))
+		Expect(session).Should(ExitCleanly())
 
 		session = podmanTest.Podman([]string{"create", "-v", "myvol6:/myvol6", ALPINE, "ls"})
 		session.WaitWithDefaultTimeout()
-		Expect(session).Should(Exit(0))
+		Expect(session).Should(ExitCleanly())
 
 		session = podmanTest.Podman([]string{"volume", "ls"})
 		session.WaitWithDefaultTimeout()
-		Expect(session).Should(Exit(0))
+		Expect(session).Should(ExitCleanly())
 		Expect(session.OutputToStringArray()).To(HaveLen(7))
 
 		session = podmanTest.Podman([]string{"system", "prune", "--force", "--volumes", "--filter", "label=label1=value1"})
 		session.WaitWithDefaultTimeout()
-		Expect(session).Should(Exit(0))
+		Expect(session).Should(ExitCleanly())
 
 		session = podmanTest.Podman([]string{"volume", "ls"})
 		session.WaitWithDefaultTimeout()
-		Expect(session).Should(Exit(0))
+		Expect(session).Should(ExitCleanly())
 		Expect(session.OutputToStringArray()).To(HaveLen(6))
 
 		session = podmanTest.Podman([]string{"system", "prune", "--force", "--volumes", "--filter", "label=sharedlabel1=slv1"})
 		session.WaitWithDefaultTimeout()
-		Expect(session).Should(Exit(0))
+		Expect(session).Should(ExitCleanly())
 
 		session = podmanTest.Podman([]string{"volume", "ls"})
 		session.WaitWithDefaultTimeout()
-		Expect(session).Should(Exit(0))
+		Expect(session).Should(ExitCleanly())
 		Expect(session.OutputToStringArray()).To(HaveLen(5))
 
 		session = podmanTest.Podman([]string{"system", "prune", "--force", "--volumes", "--filter", "label=sharedlabel1"})
 		session.WaitWithDefaultTimeout()
-		Expect(session).Should(Exit(0))
+		Expect(session).Should(ExitCleanly())
 
 		session = podmanTest.Podman([]string{"volume", "ls"})
 		session.WaitWithDefaultTimeout()
-		Expect(session).Should(Exit(0))
+		Expect(session).Should(ExitCleanly())
 		Expect(session.OutputToStringArray()).To(HaveLen(3))
 	})
 
 	It("podman system prune --all --external fails", func() {
 		prune := podmanTest.Podman([]string{"system", "prune", "--all", "--external"})
 		prune.WaitWithDefaultTimeout()
-		Expect(prune).Should(Exit(125))
-		Expect(prune.ErrorToString()).To(ContainSubstring("--external cannot be combined with other options"))
+		Expect(prune).Should(ExitWithError(125, "--external cannot be combined with other options"))
 	})
 
 	It("podman system prune --external leaves referenced containers", func() {
@@ -514,7 +500,7 @@ var _ = Describe("Podman prune", func() {
 
 		create := podmanTest.Podman([]string{"create", "--name", "test", BB})
 		create.WaitWithDefaultTimeout()
-		Expect(create).Should(Exit(0))
+		Expect(create).Should(ExitCleanly())
 
 		// Container should exist
 		Expect(podmanTest.NumberOfContainers()).To(Equal(1))
@@ -526,7 +512,7 @@ var _ = Describe("Podman prune", func() {
 
 		prune := podmanTest.Podman([]string{"system", "prune", "--external", "-f"})
 		prune.WaitWithDefaultTimeout()
-		Expect(prune).Should(Exit(0))
+		Expect(prune).Should(ExitCleanly())
 
 		// Container should still exist
 		Expect(podmanTest.NumberOfContainers()).To(Equal(1))
@@ -547,7 +533,7 @@ var _ = Describe("Podman prune", func() {
 		// Create container 1
 		create := podmanTest.Podman([]string{"create", "--name", "test", BB})
 		create.WaitWithDefaultTimeout()
-		Expect(create).Should(Exit(0))
+		Expect(create).Should(ExitCleanly())
 
 		Expect(podmanTest.NumberOfContainers()).To(Equal(1))
 
@@ -574,7 +560,7 @@ var _ = Describe("Podman prune", func() {
 		// Create container 2
 		create = podmanTest.Podman([]string{"create", "--name", "test", BB})
 		create.WaitWithDefaultTimeout()
-		Expect(create).Should(Exit(0))
+		Expect(create).Should(ExitCleanly())
 
 		Expect(podmanTest.NumberOfContainers()).To(Equal(1))
 
@@ -585,7 +571,7 @@ var _ = Describe("Podman prune", func() {
 
 		prune := podmanTest.Podman([]string{"system", "prune", "--external", "-f"})
 		prune.WaitWithDefaultTimeout()
-		Expect(prune).Should(Exit(0))
+		Expect(prune).Should(ExitCleanly())
 
 		// container 1 dir should be gone now
 		dirents, err = os.ReadDir(containerStorageDir)
